/*
 * SIP Communicator, the OpenSource Java VoIP and Instant Messaging client.
 * 
 * Distributable under LGPL license. See terms of license at gnu.org.
 */
package net.java.sip.communicator.impl.gui.keybindings;

import java.util.*;

import javax.swing.KeyStroke;

import net.java.sip.communicator.service.gui.keybindings.KeybindingSet;

/**
 * Default implementation for the wrapper of keybinding sets.
 * @author Damian Johnson
 */
class KeybindingSetImpl
    extends KeybindingSet
{
    private List <BindingWrapper> bindings;
    private List <BindingWrapper> defaultBindings;
    
    private Category category;
    
    KeybindingSetImpl(List <BindingWrapper> initial,
            List <BindingWrapper> defaultBindings, Category category)
    {
        this.bindings = new ArrayList <BindingWrapper>(initial);
        this.defaultBindings = new ArrayList <BindingWrapper>(defaultBindings);
        this.category = category;
    }
    
    /**
     * Provides current keybinding mappings. Action mappings should consist of
     * '&lt;category&gt;-&lt;action&gt;', such as 'main-nextTab'.
     * @return mapping of keystrokes to the string representation of the actions
     *         they perform
     */
    public LinkedHashMap <KeyStroke, String> getBindings()
    {
        LinkedHashMap <KeyStroke, String> bindings =
                new LinkedHashMap <KeyStroke, String>();
        for (BindingWrapper wrapper : this.bindings)
        {
            bindings.put(wrapper.shortcut, this.category.getResource() + "-"
                    + wrapper.action);
            if (wrapper.altShortcut != null) bindings.put(wrapper.altShortcut,
                    this.category.getResource() + "-" + wrapper.action);
        }
        return bindings;
    }
    
    /**
     * Provides current keybinding mappings.
     * @return mapping of keystrokes to the string representation of the actions
     *         they perform
     */
    public ArrayList <BindingWrapper> getWrappedBindings()
    {
        return new ArrayList <BindingWrapper>(this.bindings);
    }
    
    /**
     * Provides default keybinding mappings.
     * @return default mapping of keystrokes to the string representation of the
     *         actions they perform
     */
    List <BindingWrapper> getDefaultBindings()
    {
        return new ArrayList <BindingWrapper>(this.defaultBindings);
    }
    
    /**
     * Resets the bindings and notifies the observer's listeners if they've
     * changed. If the bindings can be written then they will be.
     * @param newBindings new keybindings to be held
     */
    public void setBindings(List <BindingWrapper> newBindings)
    {
        if (!this.bindings.equals(newBindings))
        {
            this.bindings = new ArrayList <BindingWrapper>(newBindings);
            setChanged();
            notifyObservers(this);
        }
    }
    
    /**
     * Provides the portion of the UI to which the bindings belong.
     * @return binding category
     */
    public Category getCategory()
    {
        return this.category;
    }
}
