/*
 * SIP Communicator, the OpenSource Java VoIP and Instant Messaging client.
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package net.java.sip.communicator.plugin.spellchecker;

import java.util.*;

import net.java.sip.communicator.service.gui.*;
import net.java.sip.communicator.service.resources.*;

import org.osgi.framework.*;

/**
 * Enabling and disabling osgi functionality for the spell checker.
 * @author Damian Johnson
 */
public class SpellCheckerActivator
    implements BundleActivator
{
    private SpellChecker checker = new SpellChecker();
    
    private static BundleContext bundleContext;
    
    public static ResourceManagementService resourcesService;
    
    /**
     * Called when this bundle is started.
     * @param context The execution context of the bundle being started.
     */
    public void start(BundleContext context) throws Exception
    {
        bundleContext = context;
        if (this.checker.isRunning()) this.checker.stop();
        
        // caches defaults
        ServiceReference resourceManagementReference =
                context.getServiceReference(ResourceManagementService.class
                        .getName());
        ResourceManagementService resourceManagementService =
                (ResourceManagementService) context
                        .getService(resourceManagementReference);
        Parameters.init(resourceManagementService);
        
        this.checker.start(context);
        
        SpellCheckerConfigForm checkerManager =
                new SpellCheckerConfigForm(this.checker);
        context.registerService(ConfigurationForm.class.getName(),
                checkerManager, null);
        
        // adds button to toggle spell checker
        Hashtable <String, String> containerFilter =
                new Hashtable <String, String>();
        containerFilter.put(Container.CONTAINER_ID,
                Container.CONTAINER_CHAT_TOOL_BAR.getID());
        context.registerService(PluginComponent.class.getName(),
                new CheckerToggleButton(this.checker), containerFilter);
        
        // adds field to change language
        /*
        context.registerService(PluginComponent.class.getName(),
                LanguageSelectionField.makeSelectionField(this.checker),
                containerFilter);
                */
    }
    
    /**
     * Stops this bundles.
     */
    public void stop(BundleContext arg0) throws Exception
    {
        this.checker.stop();
    }
    
    public static ResourceManagementService getResources()
    {
        if (resourcesService == null)
        {
            ServiceReference serviceReference =
                    bundleContext
                            .getServiceReference(ResourceManagementService.class
                                    .getName());
            
            if (serviceReference == null) return null;
            
            resourcesService =
                    (ResourceManagementService) bundleContext
                            .getService(serviceReference);
        }
        
        return resourcesService;
    }
}
