/*
 * SIP Communicator, the OpenSource Java VoIP and Instant Messaging client.
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package net.java.sip.communicator.plugin.spellchecker;

import java.awt.*;
import java.awt.event.*;
import java.util.*;

import javax.swing.*;

import net.java.sip.communicator.service.gui.*;

/**
 * Configuration controls for the spell checker.
 * @author Damian Johnson
 */
class SpellCheckerConfigForm
    extends JPanel
    implements ConfigurationForm
{
    private static final long serialVersionUID = 0;
    private SpellChecker spellChecker;
    
    SpellCheckerConfigForm(SpellChecker spellCheckerRef)
    {
        super(new BorderLayout());
        this.spellChecker = spellCheckerRef;
        Box content = Box.createVerticalBox();
        
        JPanel languageSelectionLine =
                new JPanel(new FlowLayout(FlowLayout.LEFT));
        languageSelectionLine.add(new JLabel(Resources.getString("language")
                + ": "));
        
        languageSelectionLine.add((JComboBox) LanguageSelectionField
                .makeSelectionField(this.spellChecker).makeField());
        content.add(languageSelectionLine);
        
        JPanel customDictLine = new JPanel(new FlowLayout(FlowLayout.LEFT));
        JButton editCustomDict =
                new JButton(Resources.getString("editPersonalDictionary"));
        editCustomDict.addActionListener(new ActionListener()
        {
            public void actionPerformed(ActionEvent event)
            {
                // Finds owning frame for modal property
                Frame owner = findParent(SpellCheckerConfigForm.this);
                
                ArrayList <String> customWords =
                        spellChecker.getPersonalWords();
                ArrayList <String> output =
                        WordlistCustomizationDialog.showDialog(owner,
                                customWords);
                if (output != null)
                {
                    spellChecker.setPersonalWords(output);
                }
            }
        });
        
        customDictLine.add(editCustomDict);
        content.add(customDictLine);
        add(content, BorderLayout.NORTH);
    }
    
    /**
     * Implements the <tt>ConfigurationForm.getTitle()</tt> method. Returns
     * the title of this configuration form.
     */
    public String getTitle()
    {
        return Resources.getString("spellChecker");
    }
    
    /**
     * Implements the <tt>ConfigurationForm.getIcon()</tt> method. Returns the
     * icon of this configuration form.
     */
    public byte[] getIcon()
    {
        return Resources.getImageInBytes(Resources.PLUGIN_ICON);
    }
    
    /**
     * Implements the <tt>ConfigurationForm.getForm()</tt> method. Returns the
     * component corresponding to this configuration form.
     */
    public Object getForm()
    {
        return this;
    }
    
    /**
     * Implements the <tt>ConfigurationForm.getIndex()</tt> method. Returns the
     * index the form should be placed at.
     */
    public int getIndex()
    {
      return -1;
    }
    
    /**
     * Helper method to recursively find the first instance of a Frame within
     * the component's hierarchy.
     * @param comp The component in which to check for Frame
     * @return Frame ancestor, null if none is found
     */
    private static Frame findParent(Component comp)
    {
        if (comp instanceof Frame) return (Frame) comp;
        Component parent = comp.getParent();
        if (parent != null) return findParent(parent);
        else return null;
    }
}
