/*
 * SIP Communicator, the OpenSource Java VoIP and Instant Messaging client.
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package net.java.sip.communicator.service.gui.keybindings;

import java.util.*;

import javax.swing.KeyStroke;

/**
 * Wrapper for keybinding sets. Observers are notified when there's a change.
 * @author Damian Johnson
 */
public abstract class KeybindingSet
    extends Observable
{
    /**
     * Provides current keybinding mappings.
     * @return mapping of keystrokes to the string representation of the actions
     *         they perform
     */
    public abstract HashMap <KeyStroke, String> getBindings();
    
    /**
     * Provides the portion of the UI to which the bindings belong.
     * @return binding category
     */
    public abstract Category getCategory();
    
    /**
     * Keybinding sets available in the Sip Communicator.
     */
    public enum Category
    {
        CHAT("chat"), CHAT_TOOLBAR("chatToolbar"), MAIN("main");
        
        private final String resource;
        
        Category(String resource)
        {
            this.resource = resource;
        }
        
        /**
         * Provides the name keybindings are saved and loaded with.
         * @return filename used for keybindings
         */
        public String getResource()
        {
            return this.resource;
        }
    }
}
