import java.awt.Point;
import java.awt.event.*;
import java.util.List;

import javax.swing.*;
import javax.swing.text.*;

/**
 * Listens for the pop-up trigger over misspelled words and provides a menu with
 * corrections.
 * @author Damian Johnson
 */
public abstract class CorrectionListener extends MouseAdapter {
  private JPopupMenu correctionsMenu = new JPopupMenu();
  
  /**
   * Provides a list of corrections.
   * @param word text to be checked
   * @return list of spelling corrections (null if correct)
   */
  abstract List <String> getCorrections(String word);
  
  public void mousePressed(MouseEvent event) {
    this.correctionsMenu.setVisible(false);
    handleEvent(event);
  }
  
  public void mouseReleased(MouseEvent event) {
    handleEvent(event);
  }
  
  private void handleEvent(MouseEvent event) {
    // TODO: Need to merge these results with current right click instead
    if (event.isPopupTrigger() && event.getSource() instanceof JTextComponent) {
      JTextComponent comp = (JTextComponent) event.getSource();
      Point loc = event.getPoint();
      int index = comp.viewToModel(loc);
      final Document doc = comp.getDocument();
      
      if (index != -1 && doc.getLength() != 0) {
        final Word clickedWord = Word.getWord(comp.getText(), index, false);
        List <String> corrections = getCorrections(clickedWord.getText());
        this.correctionsMenu.removeAll();
        if (corrections != null) {
          for (final String correction : corrections) {
            this.correctionsMenu.add(new AbstractAction(correction) {
              private static final long serialVersionUID = 0;
              
              public void actionPerformed(ActionEvent event) {
                try {
                  // Replaces word with correction
                  // TODO: Possibly use setMessage from the chat interface
                  doc.remove(clickedWord.getStart(), clickedWord.getText().length());
                  doc.insertString(clickedWord.getStart(), correction, null);
                } catch (BadLocationException exc) {
                  // TODO: Register as error
                  System.out.print("The program says neep! - " + exc);
                }
                
                correctionsMenu.setVisible(false);
              }
            });
          }
          
          this.correctionsMenu.show(comp, loc.x, loc.y);
        }
      }
    }
  }
}
