import java.awt.Dimension;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.List;
import java.util.zip.ZipFile;

import javax.swing.*;

import org.dts.spell.dictionary.OpenOfficeSpellDictionary;
import org.dts.spell.dictionary.SpellDictionary;

public class SpellChecker {
  private static final SpellDictionary MYSPELL_DICT;
  
  private static final String DICT_NAME = "en_US.zip";
  private static final String RESOURCE_LOC = "www.atagar.com/transfer/sipDictionaries/";
  private static final String PROTOCOL = "http://";
  
  static {
    // Downloads dictionary for JMySpell
    byte[] buf = new byte[1024];
    
    try {
      URL engDictResourceLoc = new URL(PROTOCOL + RESOURCE_LOC + DICT_NAME);
      InputStream engDictStream = engDictResourceLoc.openStream();
      File dest = new File(DICT_NAME);
      FileOutputStream outputStream = new FileOutputStream(dest);
      
      int len;
      while ((len = engDictStream.read(buf)) > 0) {
        outputStream.write(buf, 0, len);
      }
      
      // Complete the entry
      engDictStream.close();
      outputStream.close();
    } catch (MalformedURLException exc) {
      System.out.println(exc);
    } catch (IOException exc) {
      System.out.println(exc);
    }
    
    SpellDictionary tmp;
    try {
      tmp = new OpenOfficeSpellDictionary(new ZipFile(DICT_NAME));
    } catch (IOException exc) {
      System.out.println("Couldn't find dictionary");
      tmp = null;
      System.exit(1);
    }
    
    MYSPELL_DICT = tmp;
  }
  
  public static void main(String[] args) {
    JFrame frame = new JFrame();
    frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    
    final JEditorPane editorPane = new JEditorPane();
    editorPane.setPreferredSize(new Dimension(400, 500));
    
    final DocUnderliner formatter = new DocUnderliner(editorPane.getHighlighter()) {
      boolean getFormatting(String word) {
        return !MYSPELL_DICT.isCorrect(word);
      }
      
      int getCaretPosition() {
        return editorPane.getCaretPosition();
      }
      
      void promptRepaint() {
        editorPane.repaint();
      }
    };
    editorPane.getDocument().addDocumentListener(formatter);
    
    editorPane.addCaretListener(formatter.getEndChecker());
    
    editorPane.addMouseListener(new CorrectionListener() {
      List <String> getCorrections(String word) {
        if (MYSPELL_DICT.isCorrect(word)) return null;
        else return MYSPELL_DICT.getSuggestions(word);
      }
    });
    
    frame.add(editorPane);
    frame.pack();
    frame.setVisible(true);
  }
}
